@@ -78,8 +78,8 @@ class dbg():
 
 class print_dbg():
 
-    def __new__(cls, text, module):
-        cls.print_dbg(cls, text, module)
+    def __new__(cls, text: str, module: str, dbg_mode: bool = False):
+        cls.print_dbg(cls, text, module, dbg_mode)
         # super(print_dbg, cls).__new__(cls, *args, **kwargs)
 
     def __init__(self):
@@ -91,5 +91,8 @@ class print_dbg():
     def __str__(self):
         super(print_dbg, self).__str__()
 
-    def print_dbg(cls, text, module):
-        print('dbg => ' + text) if dbg.get_module(module) else None
+    def print_dbg(cls, text: str, module: str, dbg_mode: bool = False):
+        if dbg_mode:
+            print('dbg => ' + str(text)) if dbg.get_module(module) else None
+        else:
+            print(text) if dbg.get_module(module) else None
